import re


def get_content(file):
    try:
        with open(file) as f:
            return f.read()
    except FileNotFoundError:
        return "Error 1: FileNotFoundError"


def convert_to_raw_html(content):
    # Convert to paragraph
    content = re.sub(r"^([^#!*_\-+\n].*)$", r"<p>\1</p>", content, flags=re.MULTILINE)

    # Convert to headings
    content = re.sub(
        r"^(#{1,6}) +(.*)$",
        lambda m: f"<h{len(m.group(1))}>{m.group(2)}</h{len(m.group(1))}>",
        content,
        flags=re.MULTILINE
    )

    # Convert to bold
    content = re.sub(
        r"\*{2}([^*]+)\*{2}", r"<strong>\1</strong>", content, flags=re.MULTILINE
    )

    # Convert to italic
    content = re.sub(r"_([^_]+)_(?: |\n)", r"<em>\1</em> ", content, flags=re.MULTILINE)

    # Convert to strikethrough
    content = re.sub(r"~{2}([^~]+)~{2}", r"<s>\1</s>", content, flags=re.MULTILINE)

    # Convert to link
    content = re.sub(
        r"\[([^\]]+)\]\((.+?(?=\) ))\)",
        r'<a href="\2">\1</a>',
        content,
        flags=re.MULTILINE,
    )

    # Convert to image
    content = re.sub(
        r"!\[([^\]]*)\]\((.+?(?=\)\n))\)",
        r'<img src="\2" alt="\1">',
        content,
        flags=re.MULTILINE,
    )

    # Convert to unordered lists
    content = re.sub(r"^(?:-|\*|\+) (.*)$", r"<li>\1</li>", content, flags=re.MULTILINE)

    # Convert to code
    content = re.sub(r"`([^`]+)`", r"<code>\1</code>", content, flags=re.MULTILINE)

    return content


def export_as_html(filename, content):
    upper_part = """<!DOCTYPE html>
<html lang="en">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>{}</title>
        <style>
            * {{
                font-family: Helvetica, Arial, sans-serif;
            }}

            code {{
                background-color: #f3f4f6;
                border-radius: 4px;
                color: #be185d;
                font-family: Consolas, "courier new";
                padding: 2px;
            }}
        </style>
    </head>
    <body>
    \t"""

    lower_part = """
    </body>
</html>"""

    with open(f"{filename}.html", "w") as file:
        file.write(upper_part.format(filename.capitalize()))
        file.write(content)
        file.write(lower_part)


def export_as_txt(filename, content):
    with open(f"{filename}.txt", "w") as file:
        file.write(content)


def format_content(content):
    start = f'{"=" * 25} START {"=" * 25}'
    end = f'{"=" * 26} END {"=" * 26}'

    return f"{start}\n\n{content}\n{end}"