import argparse
import os
import sys

import helpers


def main():
    parser = argparse.ArgumentParser(description="Convert a markdown file to HTML")
    parser.add_argument(
        "-f", "--filename", help="filename to be converted", metavar="", type=str
    )
    parser.add_argument(
        "-o",
        "--output",
        default="str",
        help="output type (html, str or txt)",
        metavar="",
        type=str,
    )
    args = parser.parse_args()

    file = args.filename
    filename, file_extension = os.path.splitext(file)

    if file_extension != ".md":
        sys.exit("File extension must be .md.")

    content = helpers.get_content(file)
    if content == "Error 1: FileNotFoundError":
        sys.exit(f"The {file} file could not be found.")

    converted_content = helpers.convert_to_raw_html(content)

    output_type: str = args.output.strip().lower()
    match output_type:
        case "html" | "h":
            helpers.export_as_html(filename, converted_content)
        case "txt" | "t":
            helpers.export_as_txt(filename, converted_content)
        case "str" | "s":
            print(helpers.format_content(converted_content))
        case _:
            print(f"Cannot convert to {output_type}")


if __name__ == "__main__":
    main()